==> rheolef_6.5.orig.tar.gz: rheolef-6.5/skit/ptst2/csr_concat3_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

run "./csr_concat3_tst < in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst.1.valid - >/dev/null"
if test $? -ne 0; then status=1; fi

if test "$MPIRUN" != "" -a "$NPROC_MAX" -ge 2; then
  run "$MPIRUN -np 2 ./csr_concat3_tst < in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst.2.valid - >/dev/null"
  if test $? -ne 0; then status=1; fi
fi

if test "$MPIRUN" != "" -a "$NPROC_MAX" -ge 3; then
  run "$MPIRUN -np 3 ./csr_concat3_tst < in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst.3.valid - >/dev/null"
  if test $? -ne 0; then status=1; fi
fi

exit $status

==> rheolef_6.6.orig.tar.gz: rheolef-6.6/skit/ptst2/csr_concat3_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi

status=0

run "./csr_concat3_tst < $SRCDIR/in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst${QD_EXT}.1.valid - >/dev/null"
if test $? -ne 0; then status=1; fi

if test "$MPIRUN" != "" -a "$NPROC_MAX" -ge 2; then
  run "$MPIRUN -np 2 ./csr_concat3_tst < $SRCDIR/in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst${QD_EXT}.2.valid - >/dev/null"
  if test $? -ne 0; then status=1; fi
fi

if test "$MPIRUN" != "" -a "$NPROC_MAX" -ge 3; then
  run "$MPIRUN -np 3 ./csr_concat3_tst < $SRCDIR/in-animal-struct.mtx 2>/dev/null | diff $SRCDIR/csr_concat3_tst${QD_EXT}.3.valid - >/dev/null"
  if test $? -ne 0; then status=1; fi
fi

exit $status
